ApiService class

Constructors

ApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path) Future<Response>
get(String path, {Map<String, dynamic>? query}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String path, {dynamic data}) Future<Response>
put(String path, {dynamic data}) Future<Response>
toString() String
A string representation of this object.
inherited
uploadFile(String path, {required File file, String fileKey = "file", Map<String, dynamic>? data, ProgressCallback? onProgress}) Future<Response>
===================================================== 🔥 SINGLE FILE UPLOAD (Image / PDF / DOC)
uploadMultipleFiles(String path, {required List<File> files, String fileKey = "files", Map<String, dynamic>? data, ProgressCallback? onProgress}) Future<Response>
===================================================== 🔥 MULTIPLE FILE UPLOAD

Operators

operator ==(Object other) bool
The equality operator.
inherited