TabProvider class

Inheritance

Constructors

TabProvider()

Properties

activeIndex int
Active tab ka index (IndexedStack ke liye)
no setter
activeRoute String?
no setter
activeTab TabItem?
Active TabItem (null agar koi tab open nahi)
no setter
api ApiService
finalinherited
context BuildContext
getter/setter pairinherited
count int
no setter
errorMessage String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasTabs bool
no setter
isLoading bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabs List<TabItem>
no setter

Methods

activateTab(String route) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attach(BuildContext context) → void
inherited
closeAllTabs() → void
closeCurrentTab() → void
closeOtherTabs() → void
closeTab(String route) → void
Tab close karo. Agar active tab close ho raha hai → previous tab activate (ya null)
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
isActive(String route) bool
isOpen(String route) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onInit() → void
Child Provider override karega
inherited
openTab(String route, String title) → void
Already open hai → sirf activate Naya → add + activate
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reorderTab(int fromIndex, int toIndex) → void
request<T>({required Future<Response> call(), required T onSuccess(Response response), bool showLoader = true, bool showErrorLog = true}) Future<T?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited