RSMenuItem class

Constructors

RSMenuItem({required String title, required String icon, String? route, List<RSMenuItem> children = const [], String? badge, required String id})
const

Properties

badge String?
final
children List<RSMenuItem>
final
hasChildren bool
no setter
hashCode int
The hash code for this object.
no setterinherited
icon String
final
id String
final
route String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited