MenuItemData class
Constructors
-
MenuItemData({required String title, required IconData icon, String? route, List<
MenuItemData> children = const [], bool isExpanded = false, bool isActive = false})
Properties
-
children
→ List<
MenuItemData> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
final
- isActive ↔ bool
-
getter/setter pair
- isExpanded ↔ bool
-
getter/setter pair
- route → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited