AppValidatorRule class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
email(
) → ValidatorFunction -
maxLength(
int len) → ValidatorFunction -
minLength(
int len) → ValidatorFunction -
mobile(
) → ValidatorFunction -
number(
) → ValidatorFunction -
password(
) → ValidatorFunction -
required(
{String? msg}) → ValidatorFunction