ErpTheme class

Constructors

ErpTheme(ErpThemeVariant variant)
const

Properties

accent Color
no setter
bg Color
no setter
border Color
no setter
hashCode int
The hash code for this object.
no setterinherited
headerBg Color
no setter
icon IconData
no setter
isDark bool
True for themes where bg/surface are dark
no setter
isWarm bool
True for themes where bg is warm-tinted
no setter
name String
no setter
primary Color
no setter
primaryGradient List<Color>
no setter
rowAlt Color
no setter
rowHover Color
no setter
rowSelected Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surface Color
no setter
text Color
no setter
textLight Color
no setter
variant ErpThemeVariant
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const List<ErpThemeVariant>