SidebarMenuItem class

Inheritance

Constructors

SidebarMenuItem({Key? key, required String title, required String icon, required bool isExpanded, required bool isActive, bool isSubItem = false, bool hasSubItems = false, bool isSubExpanded = false, String? badge, required VoidCallback onTap, required Color themeColor})
const

Properties

badge String?
final
hashCode int
The hash code for this object.
no setterinherited
hasSubItems bool
final
icon String
final
isActive bool
final
isExpanded bool
final
isSubExpanded bool
final
isSubItem bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeColor Color
final
title String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SidebarMenuItem>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited