AppStorage class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clear(
) → Future< void> -
contains(
String key) → bool -
getBool(
String key, {bool defaultValue = false}) → bool -
getDouble(
String key) → double? -
getInt(
String key) → int? -
getObject(
String key) → Map< String, dynamic> ? -
getString(
String key) → String? -
init(
) → Future< void> - INIT — App start me sirf 1 baar call hoga
-
remove(
String key) → Future< void> -
setBool(
String key, bool value) → Future< void> -
setDouble(
String key, double value) → Future< void> -
setInt(
String key, int value) → Future< void> -
setObject(
String key, Map< String, dynamic> value) → Future<void> -
setString(
String key, String value) → Future< void>