NumberEngine class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
divide(String? value, double by, {int decimal = 2})
→ String
-
-
format(String? value, {int decimal = 2, bool useGrouping = true})
→ String
-
Core formatter (base function)
-
multiply(String? value, double by, {int decimal = 2})
→ String
-
-
percentage(String? value1, String? value2, {int decimal = 2, bool multiplyBy100 = true, bool showSymbol = true, bool useGrouping = false})
→ String
-
-
ratio(String? value1, String? value2, {int decimal = 4})
→ String
-