ToastEngine class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
actionToast(
BuildContext context, {required String message, List< ToastAction> ? actions, Duration duration = const Duration(seconds: 3), Color background = const Color(0xFF2A3042)}) → void -
error(
String msg) → void -
info(
String msg) → void -
show(
String message, {ToastGravity gravity = ToastGravity.BOTTOM, Color background = const Color(0xFF323232), Color textColor = Colors.white, double fontSize = 14}) → void -
success(
String msg) → void -
warning(
String msg) → void