AppValidator class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
aadhar(String? value)
→ String?
-
-
email(String? value, {String message = "Enter valid email"})
→ String?
-
-
gst(String? value)
→ String?
-
-
integer(String? value, {String message = "Enter valid integer"})
→ String?
-
-
maxLength(String? value, int length, {String? message})
→ String?
-
-
maxValue(String? value, num max, {String? message})
→ String?
-
-
minLength(String? value, int length, {String? message})
→ String?
-
-
minValue(String? value, num min, {String? message})
→ String?
-
-
mobile(String? value, {String message = "Enter valid mobile number"})
→ String?
-
-
multi(String? value, List<ValidatorFunction> validators)
→ String?
-
-
number(String? value, {String message = "Enter valid number"})
→ String?
-
-
pan(String? value)
→ String?
-
-
password(String? value, {String message = "Password must contain upper, lower, number & symbol"})
→ String?
-
-
required(String? value, {String message = "This field is required"})
→ String?
-